package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(<@`````````0```````
M`+%X``````!``#@`"0!``!<`%@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````&``````````8``````````$````!
M````!0```````````````````````````````````````*.H````````HZ@`
M```````0``````$````&````````J\@```````"[R````````+O(````````
M!+@````````%$````````!```````@````8```````"KV````````+O8````
M````N]@````````!X`````````'@``````````@````$````!`````````)0
M`````````E`````````"4``````````D`````````"0`````````!&1TY5``
M```$````````G3````````"=,````````)TP`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O(````````N\@`````
M``"[R`````````0X````````!#@``````````2]L:6(O;&0M;75S;"US,SDP
M>"YS;RXQ``````0````4`````T=.50!CYP\FZV#3*^A:,L^D^1[)@U%,*0``
M```````1````10````0````(@`1`!0`0$""$`(:`!!``*`D$``D"`*&""`($
MND$8@(@`````````10```$D```!-````3@```%4```!6````5P````````!9
M````6@````````!;````7````%X``````````"U'WLX?W\5N?)I_:@[OT^NV
MF\4N#O&-N`[D_R!\U&35'%AQV6^+`;*;PT^8+#_EPH?7^D)@;*'Z?)+CN@'&
M1^/2/,-59LRO9]-P!XCLU45#[=MB,\PEC!6;G*E_"@*GX%">&FM)^^"C````
M```````````````````````````````````````#```(````````&"@`````
M`````````F@2`````````````````````````````8T2````````````````
M`````````````$L2`````````````````````````````G<2````````````
M`````````````````6$2`````````````````````````````#T2````````
M`````````````````````1(2`````````````````````````````=`2````
M`````````````````````````*,2`````````````````````````````*PB
M`````````````````````````````2H2````````````````````````````
M`;42`````````````````````````````E82````````````````````````
M`````7(2`````````````````````````````/42````````````````````
M`````````F\2`````````````````````````````KDA````````````````
M`````````````#<2`````````````````````````````K@1````````````
M`````````````````:@1`````````````````````````````1D2````````
M`````````````````````C\2`````````````````````````````%L2````
M`````````````````````````>\2`````````````````````````````KH1
M`````````````````````````````)02````````````````````````````
M`A82`````````````````````````````!\@````````````````````````
M`````3\2`````````````````````````````-8@````````````````````
M`````````K<A`````````````````````````````&,2````````````````
M`````````````/`2`````````````````````````````%,2````````````
M`````````````````$02`````````````````````````````!`2````````
M`````````````````````@T2`````````````````````````````H`2````
M`````````````````````````8$2`````````````````````````````'(@
M`````````````````````````````H<2````````````````````````````
M`B\2`````````````````````````````=P2````````````````````````
M``````$2`````````````````````````````^,2````````````````````
M`````````B$2`````````````````````````````IT2````````````````
M``````````````D1`````````````````````````````?T2````````````
M`````````````````&02`````````````````````````````ET2````````
M`````````````````````!@2`````````````````````````````/L2````
M`````````````````````````-$2`````````````````````````````4X6
M`````````````````````````````HX2````````````````````````````
M`J42`````````````````````````````(X2````````````````````````
M`````)P2`````````````````````````````&D2````````````````````
M`````````3$2`````````````````````````````DH2````````````````
M`````````````0P2`````````````````````````````+L@````````````
M`````````````````<82`````````````````````````````),2````````
M`````````````````````<L2`````````````````````````````VL2```*
M````````.!@````````&.````W@2```*````````0,@`````````S@```K(2
M```*````````'T@````````"@````:(2```+````````7)```````````@``
M`N\2```*````````*H``````````!@```^\2```(````````&"@`````````
M`@```R02```*````````*H@````````";````SD2```*````````/E``````
M```"=````X00```4````````P(```````````````PH2```*````````-"@`
M````````=@```S$2```*````````-*``````````=````T\2```*````````
M*2``````````.````V`2```*````````6*`````````!E@```Y`2```*````
M````-U@`````````P````[\0```4````````P-@``````````````\02```*
M````````+/@`````````-````U<2```*````````(?@`````````/````Q@2
M```*````````+3`````````!8@```P`1```3````````P'@`````````"```
M`[@0```4````````P(```````````````XD2```*````````(<@`````````
M`````^P2```*````````6#``````````;````]$2```*````````-R@`````
M````+````Z(2```*````````*5@````````!)````_42```*````````6C@`
M```````"5````N(2```*````````+I@````````%C`!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E
M:P!G971P:60`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR`&QS=&%T
M`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'9F
M<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES
M=&5R7V9R86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`')E860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!M96UC<'D`7U]S
M=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?
M9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!S=')C<'D`<F5A9&1I<@!S;G!R:6YT9@!S=')T
M;VL`<W1R9'5P`'!T:')E861?871F;W)K`'-P<FEN=&8`7U]L:6)C7W-T87)T
M7VUA:6X`7U]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"US,SDP>"YS
M;RXQ`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N=%]E>&5C`&UY7W!A<E]P;`!P
M87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P87)?9&EE
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]S=&%R=%]C`'-H85]U
M<&1A=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P`%]?8G-S7W-T87)T`'!A
M<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?<')O8P!?961A=&$`
M7V5N9`!P87)?8F%S96YA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`
M<VAA7VEN:70`<VAA7V9I;F%L`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#
M3U)%`````````````+O(``````````P````````C$````````+O0````````
M``P````````BJ````````+^@``````````P````````8*````````+_0````
M``````P````````?2````````+_@``````````P```````!<D````````,``
M``````````P```````#``````````,`8``````````P```````!?G```````
M`,`@``````````P```````!<^````````,`P``````````P```````!=F```
M`````,`X``````````P```````!=G````````,!```````````P```````!?
MD````````,!(``````````P```````!<_@```````,!0``````````P`````
M``!?F````````,!@``````````P```````!?@````````,!H``````````P`
M``````!?A@```````,!X``````````P```````!?H@```````+^(````!@``
M``H``````````````````+^0````"P````H``````````````````+^8````
M%0````H``````````````````+^H````&@````H``````````````````+^P
M````'0````H``````````````````+^X````'P````H`````````````````
M`+_`````*0````H``````````````````+_(````*P````H`````````````
M`````+_8````+`````H``````````````````+_H````,0````H`````````
M`````````+_P````.````#@``````````````````+_X````00````H`````
M`````````````+W0`````@````L``````````````````+W8`````P````L`
M`````````````````+W@````!`````L``````````````````+WH````!0``
M``L``````````````````+WP````!P````L``````````````````+WX````
M"`````L``````````````````+X`````"0````L``````````````````+X(
M````"@````L``````````````````+X0````"P````L`````````````````
M`+X8````#`````L``````````````````+X@````#0````L`````````````
M`````+XH````#@````L``````````````````+XP````#P````L`````````
M`````````+XX````$`````L``````````````````+Y`````$0````L`````
M`````````````+Y(````$P````L``````````````````+Y0````%@````L`
M`````````````````+Y8````%P````L``````````````````+Y@````&```
M``L``````````````````+YH````&0````L``````````````````+YP````
M&P````L``````````````````+YX````'`````L``````````````````+Z`
M````'0````L``````````````````+Z(````'@````L`````````````````
M`+Z0````(0````L``````````````````+Z8````(@````L`````````````
M`````+Z@````(P````L``````````````````+ZH````)`````L`````````
M`````````+ZP````)0````L``````````````````+ZX````)@````L`````
M`````````````+[`````)P````L``````````````````+[(````*`````L`
M`````````````````+[0````*@````L``````````````````+[8````+0``
M``L``````````````````+[@````+@````L``````````````````+[H````
M+P````L``````````````````+[P````,`````L``````````````````+[X
M````,@````L``````````````````+\`````,P````L`````````````````
M`+\(````-`````L``````````````````+\0````-0````L`````````````
M`````+\8````-@````L``````````````````+\@````-P````L`````````
M`````````+\H````.0````L``````````````````+\P````.@````L`````
M`````````````+\X````.P````L``````````````````+]`````/`````L`
M`````````````````+](````/0````L``````````````````+]0````/@``
M``L``````````````````+]8````/P````L``````````````````+]@````
M0`````L``````````````````+]H````00````L``````````````````+]P
M````0@````L``````````````````+]X````0P````L`````````````````
M`+^`````1`````L``````````.OO\'``)+D$``^G^_]@XP#P```DZ^_Q$``$
M!_[C$/`X`"3`$```4K?2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!2MN,0$```
M!`?Q#1#C$!`,`!3`]/___^4`````P!```%*JXQ`0```$!_$-$.,0$`P`%,#T
M____U0```!C`$```4I[C$!````0'\0T0XQ`0#``4P/3____%````,,`0``!2
MDN,0$```!`?Q#1#C$!`,`!3`]/___[4```!(P!```%*&XQ`0```$!_$-$.,0
M$`P`%,#T____I0```&#`$```4GKC$!````0'\0T0XQ`0#``4P/3___^5````
M>,`0``!2;N,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```%)BXQ`0```$
M!_$-$.,0$`P`%,#T____=0```*C`$```4E;C$!````0'\0T0XQ`0#``4P/3_
M__]E````P,`0``!22N,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```%(^
MXQ`0```$!_$-$.,0$`P`%,#T____10```/#`$```4C+C$!````0'\0T0XQ`0
M#``4P/3___\U```!",`0``!2)N,0$```!`?Q#1#C$!`,`!3`]/___R4```$@
MP!```%(:XQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```4@[C$!````0'
M\0T0XQ`0#``4P/3___\%```!4,`0``!2`N,0$```!`?Q#1#C$!`,`!3`]/__
M_O4```%HP!```%'VXQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```4>KC
M$!````0'\0T0XQ`0#``4P/3___[5```!F,`0``!1WN,0$```!`?Q#1#C$!`,
M`!3`]/___L4```&PP!```%'2XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`
M$```4<;C$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!1NN,0$```!`?Q
M#1#C$!`,`!3`]/___I4```'XP!```%&NXQ`0```$!_$-$.,0$`P`%,#T___^
MA0```A#`$```4:+C$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!1EN,0
M$```!`?Q#1#C$!`,`!3`]/___F4```)`P!```%&*XQ`0```$!_$-$.,0$`P`
M%,#T___^50```EC`$```47[C$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0
M``!1<N,0$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```%%FXQ`0```$!_$-
M$.,0$`P`%,#T___^)0```J#`$```45KC$!````0'\0T0XQ`0#``4P/3___X5
M```"N,`0``!13N,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```%%"XQ`0
M```$!_$-$.,0$`P`%,#T___]]0```NC`$```43;C$!````0'\0T0XQ`0#``4
MP/3___WE```#`,`0``!1*N,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!``
M`%$>XQ`0```$!_$-$.,0$`P`%,#T___]Q0```S#`$```41+C$!````0'\0T0
MXQ`0#``4P/3___VU```#2,`0``!1!N,0$```!`?Q#1#C$!`,`!3`]/___:4`
M``-@P!```%#ZXQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```4.[C$!``
M``0'\0T0XQ`0#``4P/3___V%```#D,`0``!0XN,0$```!`?Q#1#C$!`,`!3`
M]/___74```.HP!```%#6XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```
M4,KC$!````0'\0T0XQ`0#``4P/3___U5```#V,`0``!0ON,0$```!`?Q#1#C
M$!`,`!3`]/___44```/PP!```%"RXQ`0```$!_$-$.,0$`P`%,#T___]-0``
M!`C`$```4*;C$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!0FN,0$```
M!`?Q#1#C$!`,`!3`]/___14```0XP!```%".XQ`0```$!_$-$.,0$`P`%,#T
M___]!0``!%#`$```4(+C$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!0
M=N,0$```!`?Q#1#C$!`,`!3`]/___.4```2`P!```%!JXQ`0```$!_$-$.,0
M$`P`%,#T___\U0``!)C`$```4%[C$!````0'\0T0XQ`0#``4P/3___S%```$
ML,`0``!04N,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```%!&XQ`0```$
M!_$-$.,0$`P`%,#T___\I0``!.#`$```4#KC$!````0'\0T0XQ`0#``4P/3_
M__R5```$^,`0``!0+N,0$```!`?Q#1#C$!`,`!3`]/___(4```40`````.MO
M\#``)./P_SC_<>,P\*@`).-`\*``)%`@\+1!0/"@03#PJ$$@\+2R3P"PZ[L`
M(``-LD\`L=('\,"P*,#E___]X,1(``!0)\0H``!/_+D$`#3`Y?___Q7$&```
M3_R5`!``IX0`ML`P``!0(>-0,```!%B@\+3LF@`$`-BY%`#IXV6P```$ZRX`
M`P`-E@-DBJ>J``/`Y?___U3C$/"H``3`,```'\CC`!````3C,"`(`"3C`"``
M`"2Y!`!2Q"L``%!>P$```!^YXT!0&``DQ"@``%`QXR!0$``D6)#PM.R<`,4!
M?NSI``,`V.P)__\`V$$P$`BG*``$IP$``:=T`(*(```!N10`0NP2``$`V.OD
M``,`#;D4`&'C0#````3C3E```"3K%@`#``WC8#`(``3C85```"2G*@`"ISL`
M$*<&_^/L:0`#`-BY%`"6N10`2NNI``,`#4$J4`"G:0``Y4@@````P#````/^
MQ"@``%`/P.7___SF["@`5`!^Q"@``%`&06#PO,#E___]^[D$`#:Y!`"2P"``
M`!XWP.4```$W["@`1P!\Q"@``$_QP.7___[XP.7___ZUU0?PP+`HIW0`6;D$
M`"GK;_#X``0'_L#E___^%\0K``!/VNPH`$X`?,#E___\7L`P``!/8>,@,```
M!.-"L```!)(`24:G]/\XXS`P```$XS!0(``DIR@`!4$P$!#L+O]V8':G]/^4
MQ"@``$^UP.7___U,I_3_J<!0``!/J>,@4````J>$``?`Y0``#Z&G]/^QN00`
M-L`@```=L\#E````V\0K``!/E.PH_Z0`?*?T_^VG:``$I_3_;L#E___\5J<I
M``'`Y?___?&Y!``OP#`````2XS`P```8I_O_8*<)``#C`/```"3`]`````D'
M!P<'``"9Z`<'!P?K;_`P`"1!0"`(X_#_6/]QQ&@``$[LY4CPH```Q%@``$[&
MXS`@!``4Q"@``$[8P.7___W?ZV_PV``$!_X'!P<'P!```$\DP"```$\A[!(`
M"H!DQ!@``$Z[[!@`!`!\!_$'_@<'!P<'!\`0``!/$,`@``!/#;D)`!+K`0`#
M``KK,0`_``RY"``PZS,``0`*[#@`#0!\Q!@``$Z6[!@`!P!\P"```$[T!_$'
M_@<'!P<'!^N_\%@`),"P``!.Z>/P_V#_<94`L`"G=``CP!```$YGXQ`0```"
MIX0`",0H``!.E\#E___[1L#E____K<`@``!.9N,0(````J>$``C`(```/8K`
MY?___!62`;``Z[_P^``$!_X'!P<'P!```$YTXQ`0```"IX0`%^OO\'``),`P
M``!.L>/P_V#_<<`@```]:\#E___]QNOO\1``!,#T____CL#T____B^MO\#``
M)./P_V#_<>PH`%P`?,08``!.(^-P$````J>$`%.Y!`""N00`8^,`(```E+D$
M`)*5`"``IX0`3NP(``P]?D&0D`'C`)```)25`)``IW3_]AN8XZ!P```"IX0`
M'[D4`)FY!`"WN00`2;D$`#BY!``JP.7___OP["8`"0!^02F@`)4](`"GA``/
M0;"P"..@L````J=T_^FY!``JZV_PT``$!_Y!J:`!N>EP.[D$`"KK0P`#``I0
M0&``ZV_PT``$!_ZGJ0``N00`*NMO\-``!`?^IY@``*?T_[\'!P<'ZZ_P4``D
MX_#^R/]QLD\`L+D$`*+KNP`@``U!,/"@LD\`L=('\3"P*,#E___[ANPF`"$`
M?A@2ISA``%@@\+C`*P``\`#L(P`(@':E#Z``["``$V!VN00`*J<Y``+`Y?__
M_&P0$J<:__^($``?I_0`!*<8``#5!_$PL"BY%``AIW0`!NNO\8@`!`?^P.7_
M__K5ZX_P0``DX_#^R/]QLD\`@.N(`"``#;)/`('2!_$P@"CL*``)`'RY!`"R
ME0`@`*=T``O5!_$P@"BG=`"1ZX_Q>``$!_[`Y?__^\"Y!`"2["C_\@!\N00`
M*<#E___ZANPH`&$`?$&@(!.5+B`3IW0`!I4`H`&GA/_PE2X@$Z>$`%ZG"```
MN00`.KD$`!NG20``LEX`0Z<4__ZY"0!*IRD``+)>`"&G%/_^N0D`*QHDIRH`
M`KD4`"+`Y?__^B>Y!`!:P#```!N8N00`HKD$`$O`Y?__^ZNY!``J03#PH,#E
M___[Q.PH``W_?E@`\+BG6$``P`L``/``[`4`*X!VN00`*L#E___[`KD$`"K`
MY?___*VY!``IP.7___HH[";_I0!\N00`*<#E___\,+D$`"O`Y?__^@NG]/]_
ME2Z@`:=T_Z*5`*`"IX3_B*?T_YRY!``JP.7___]8I_3_V,#E___Z)>MO\#``
M)./P_TC_<;)/`&#K9@`@``VR3P!AN00`LM('\+!@*+D$`*.5/3``IW0`!$&@
M,`&G"```N00`&J>)``"Y!``KLEX`@:<4__Y!,/"LN0D`BL#E___^;NPH`)<`
M?*<(``"GV0``N00`XK)>`-ZG%/_^N0D`TNR-`';`9>,`\*P`%,38``!,@NMP
M``,`#>,@L```E+D$`$N5`+``IW0`#:?T`.9!0$`!XR!```"4E0!``*>$``7L
M)O_W/7ZY"0!+N10`E$$HD`*Y!`"'XX#0```(P.7___EHXR"````D["@`.0!\
MXS#0```$XU"P``"0X^<P```$0E#@`$%PL`$8!>Q6`!``?*?T`#SC$'```)!"
M$+`!07!P`1@![!@`,@!\0@#PH+D$`+Z5/?"@0>#@`:=T_^V2/;``I]D``.--
MH```D$)-L`&GVP`![$;_^0!\U0?PL&`HIW0`E>MO\.@`!`?^IYD``..)H```
MD$*)(`"GFP`![(;_^0!\I_3_Z[D$`+ZG]/_9Q-@``$P`XW#0```$XQ!P```"
MIX0`;KD$`$>GF```&"FGF@`!04!`".,P0````J=T__BG*@`#N10``NL@``,`
M#<`P``!,:.,0,```$J=T`#;`4```3&#E3%````'`Y?__^.#C(/"@`"3L*/^Q
M`'RY%`#IN00`-^M^``,`#;D$`$?`Y?__^#[C(/"@``3C(-```"10D/"LXU#P
MH``$IYH``;D4`)GK.0`#``U!$U``Y4@0````I_3_*KD$`#*Y!``GP.7___F^
MXR#PH``DXR#0```D["C_?`!\N10`2>MT``,`#:?T_]BGF0``I_3_*J<I`!"G
MF```I_3_I<#E___XX>MO\#``),`0``!+H>/P_UC_<>.P$```!,!0```Z+,1(
M``!+@<`P```9];)/`*#KJ@`@``VR3P"AXRN@```$P&```!M(P.7___D,N00`
M5N5(\*```,!````*JN,KH```!,`P```9Y<#E___X2^MO\-@`!`?^!P<'![)/
M`"#`$```2V;K,@`@``WC0!````2R3P`QP%```#GOXR0P```$Q$@``$M!P#``
M`!FUP/3___C9ZV_P,``DX_#P`/]QXP#_^``@X_#P`/]QXP#_^``@X_#_4/]Q
MXP#PJ``@XQ#PJ`)QLD\`D.N9`"``#;)/`)%!L/"FT@<0`)`HP.7___>BP&``
M`!FAN00`4L!````9GKD$`"NG.1`!P.7___>#["@`5?]^N00``N.`\*<!<;D$
M`"NY!``X[``0`"!QITD0`,#E___WK[D$`&+L)``_`'ZG*@`!N10`(L#E___W
MX[D$`*+L*``S`'RY%`"V["@`!Z!EN>BP,KEA0(/LJ``A(&6Y!``XN00`2[D$
M`"KLL!`!(''`Y?__]V9!6Z``D@!0`./@\*@"<=4'X`"0**=T`!*Y!``JZV_P
MX`($!_ZYZ+!(N6%`I*?T_]ZGJ0``I_3_ZL#E___W]P<'!P?`]/___VP'!^MO
M\#``)./P\`#_<>,`__@`(./P_KC_<>,`\4``(.,0\4`!<;D$`+*Y!`"3LD\`
M<$$P\*SK=P`@``W`(```&1RR3P!QT@<0`'`HP.7___P_ISD`+[D$`**Y!``K
MP.7___F@["@`&0!\P"```!D*N00`.\#E___]D[D$`"OC@/%``7'5!X``<"BG
M=`#OZV_Q>`$$!_ZY!``IP.7___BBP#```!CVP.7___A\N00`4NPH_]T`?$&0
M\4!!@/"PE0!0`*>$`)CLJ``/`'RG"```N00`-;D$`"JR70`RIQ3__J>$`'BG
M"```ITD``+D$`&6R7@!&IQ3__KGI4"3C$$___W'L40`WH&6YZ5`!IP$``:>$
M``Z5+Q``IW0`()(`$`#C$!___W'L40`9@&3KX``!``R5+Q``IW0`$9(`$`#K
M+Q___U6G=``*ZP`?__]2XQ`?_O]QI^?_[Z<(``"G*0``N00`-;)>`".G%/_^
MN0D`):<(``"G20``N00`:Z?I#_^R7@!&IQ3__KD)`$M!!"`![`[_;2!EX[#P
MH``DN00`*<!@```8=\!````8[J<Y$`#`Y?__]D>G6!``IRH``>PE`"C`=Z?T
M``&5`*`!IW0`&L`P```87J<I``#`Y?__]^*Y!`!2["C_0P!\E0!0`*=T_VSL
MJ``'`'R5+J``IX3_YJ<I``'`4```&#>G]/^SN00`.+D$`"G`Y?__^$3L)O_:
M`'Y8$/#(I3^``,`;``#P`.P3_]!@=KD$`"FG.0`!P.7___A0[";_Q@!^N00`
M.<`@```8&,#E___\H[D$`"G`Y?__]\"G]/\-P.7___:[!P<'!^N_\%@`)*<Y
M`"_C\/]@_W&Y!`"RP.7___;,["@`!0!\0;`@`;D$`"OKO_#X``3`]/__]Y\'
M!P<'ZZ_P4``DX_#P`/]QXP#_^``@X_#_6/]QXP#PH``@LD\`L.,0\*`!<>N[
M`"``#;)/`+'2!Q``L"CL*`!K`'RY!``RE0`@`*>$`&2G"```ITD``+)>`$*G
M%/_^IPD0`+D)`$.G2P`![$``=R!E0:#PH+D$`"K`Y?__]6"G"```ISD``+D$
M`%JR7@`UIQ3__N,0/___<>P:`!_`9;GIH.&G$0`!IW0`1^M.``$`#)4O$`"G
M=``1D@`0`.LO'___5:=T``KK`!___U+C$!_^_W&G1__ON00`*J<Y`"_`Y?__
M]DWL*``7`'SL*@`S(&6Y!``JP.7___<BXS#PH`%QU0<P`+`HIW0`+>NO\/@!
M!`?^XR#PH`%QU0<@`+`HIW0`(<`@```75>NO\/@!!,#T___W!94O$`"G=/_/
MD@`0`.,0'___<>P:_[)@9*?T_\62`"``I_3_SJ<I``"G]/_/P.7___7L!P<'
M!P<'ZZ_P4``DX_#_4/]QLD\`H.NJ`"``#;)/`*%!L/"DT@?PJ*`HN00`.\`@
M```7*\#E___Z1>PH`"X`?.-`\*0`%,0H``!(:.L4``,`#>,0(```".-0$`@`
M!.-0$```).Q8_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[P"```!<`
MP.7___H:[";_V`!\N00`.\`@```6^L#E___Z#^PH`"X`?.,0\*0`%,18``!(
M,NOA``,`#>/@4```".,`X`@`!.,`X```).P(_^,`?.,PX!``!.,PX`@`)$'@
MX`CL-O_X`'RY!``[P"```!;/P.7___GD[";_V`!\N00`.\`@```6R,#E___Y
MV>PH`"X`?.-0\*0`%,3H``!'_.M%``,`#>-`X```".,P0`@`!.,P0```).PX
M_^,`?.,@0!``!.,@0`@`)$%`0`CL)O_X`'RY!``[P"```!:=P.7___FN[";_
MV`!\N00`.\`@```6E\#E___YH^PH`"X`?.,P\*0`%,0H``!'QNL3``,`#>,0
M(```".-`$`@`!.-`$```).Q(_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY
M!``[P"```!9LP.7___EX[";_V`!\N00`.\`@```69<#E___Y;>PH`"X`?.,0
M\*0`%,1(``!'D.M1``,`#>-00```".,`4`@`!.,`4```).P(_^,`?./@4!``
M!./@4`@`)$%04`CLYO_X`'RY!``[P"```!8ZP.7___E"[";_V`!\N00`.\`@
M```6-\#E___Y-^PH`"X`?.-`\*0`%,18``!'6NLT``,`#>,P4```"./@,`@`
M!./@,```).SH_^,`?.,@,!``!.,@,`@`)$$P,`CL)O_X`'RY!``[P"```!8,
MP.7___D,[";_V`!\N00`.\`@```5V<#E___Y`>PH`"X`?./@\*0`%,0H``!'
M).L>``,`#>,0(```".,P$`@`!.,P$```).PX_^,`?.,`$!``!.,`$`@`)$$0
M$`CL!O_X`'RY!``[P"```!6NP.7___C6[";_V`!\N00`.\`@```5T<#E___X
MR^PH`"X`?.,0\*0`%,0X``!&[NM!``,`#>-`,```".,`0`@`!.,`0```).P(
M_^,`?.-00!``!.-00`@`)$%`0`CL5O_X`'RY!``[P"```!6FP.7___B@[";_
MV`!\N00`.\`@```5H,#E___XE>PH`"X`?.,P\*0`%,1(``!&N.OC``,`#>/@
M0```".-0X`@`!.-0X```).Q8_^,`?.,@X!``!.,@X`@`)$'@X`CL)O_X`'RY
M!``[P"```!5UP.7___AJ[";_V`!\N00`.\`@```5;\#E___X7^PH`"X`?.-0
M\*0`%,3H``!&@NL5``,`#>,0X```".,@$`@`!.,@$```).PH_^,`?.,`$!``
M!.,`$`@`)$$0$`CL!O_X`'RY!``[P"```!5$P.7___@T[";_V`!\N00`.\`@
M```5!L#E___X*>PH`"X`?.,0\*0`%,0H``!&3.LQ``,`#>,P(```".,`,`@`
M!.,`,```).P(_^,`?.-`,!``!.-`,`@`)$$P,`CL1O_X`'RY!``[P"```!3;
MP.7___?^[";_V`!\N00`.\`@```5",#E___W\[D$`#+L*``)`'S`(```%//`
MY?__^5"Y!``[P"```!3^P.7___?@N00`,NPH``D`?,`@```4_,#E___Y/;D$
M`#O`(```%/K`Y?__]\VY!``R["@`&@!\P"```!2:P.7___DJU0?PJ*`HIW0`
M(\`P```4]<`@```4K.NO\0``!,#T___Y&;D$`#O`(```%-[`Y?__]ZFY!``R
M["C_Y0!\P"```!2DP.7___D&I_3_W,#E___S(P<'!P?KO_!8`"3`(```%)3C
M\/]0_W&R3P"P03#PI.N[`"``#;)/`+'2!_"HL"C`Y?__]W_L*``<`'R_(2``
MIX0`%\`G````,+F$``*Y`P`0[#$_OP%5U0?PJ+`HN10`(Z=T``KKO_$(``0'
M_J<X``"G]/_SP.7___+F!P=@`/"`8"#PB&!`\)!@8/"8ZS_P&``DQ!@``$69
MX_#_./]QN00`,D$`\6BR3P`@05#PR.M"`"``#;)/`$'C(!````32!_#`0"CC
M`/"P`"3C4/"X`"3E2/"@``'E2/"H``!!0/"@P.7___4`IRD`_\#E___T2P<'
M!P?KC_!``"3CX/``\''C\/``_W'C`/_X`""Y(0#^IR3_^+D$`/[C\/]0_W'C
M`/"H`"#C$/"H$'&Y!`""LD\`H*=)``+KJ@`@``VG.0``LD\`H=('$`"@*,#E
M___R:^R2__\`V>P),(``5>R4`+H`?+D)`)!!L/"@[)0`GP!\N00`.;D$`"BG
M20``P.7___)2["@`N/]\N00`.[D$`"C`00`!``C`Y?__\N7L*`"E_WZY%``R
M[#P`>`=]XQ._^/]Q[!L`<D!E[$$^OP!5P%```$43U0=0`!``IX0`?>,0'___
M<>P;`&%`9>Q(`"T`?.Q(`!P!?.Q(``X"?,#@``!$_-4'X``0`*>$`&;C$!__
M_W'`(```1/'5!R``$`"GA`!;XQ`?__]QP#```$3FU0<P`!``IX0`4.,0'___
M<>P;`#1`9<!```!$V-4'0``0`*>$`$+C4!___W'`X```1,VY!``5U0?@`%``
MIX0`->,07___<<`@``!$P-4'(``0`*>$`"K$"```1+CC$%_^_W'C`%_^_R"G
MA``?XQ!?_?]Q[!O_TJ!EPI0``0``P#'__P``[)/_9V!DIRG__^.`\*@0<=4'
M@`"@**=T`"/KC_#P$`0'_KGIL"&Y"``II_3_\*<+___`(?__``"Y@0`"IPL`
M`:?T_T#`(```$V;`Y?___LC`(```$UG`Y?___L+`Y?__\:'K[_!P`"3C\/]@
M_W'`Y?__\2C`Y?__\K7L*``&`'SC("````3K[_$0``0'_@<'!P?K;_`P`"3C
M\/]0_W&R3P"@N00`LNNJ`"``#4$P\*2R3P"AP"```!,TT@?PJ*`HP.7___7E
M["@`"0!\N00`8I4`(`"G=``2U0?PJ*`HIW0`-[D$`#O`(```$QOK;_#@``3`
M]/__]S2G"```N00`&[D$`#:G20``LEX`0Z<4__ZY"0!&IRD``+)>`"&G%/_^
MN0D`*T$B0`+`Y?__\.NY!`!+P%```!*-N00`LL`P```3`\#E___R;J?T_\C`
MY?__\2GK;_`P`"3C\/X@_W&R3P!PZW<`(``-LD\`<<`0``!#Z]('\=AP*-(/
M\+@0$-('\,@0(-(O\.@0*-(/\-`06-('\.`0:$&0\+2Y!`#2N00`.<`@```2
M2<#E___U<>PH``D`?+D$`+*5`"``IW0"1L#E___P?\#E___R#.PH`0P`?..`
M(````J>$`0:G"```IRD``+D$`#BR7@`CIQ3__KD)`"CK(@`!``VG*P`!P.7_
M__"`XT"```"4N00`LKD$`&*5`(``IX0`%[D$`"NYA`!$P#```!*)P.7___'[
M08"``4&PL`+C0(```)25`(``IW3_[4&@\/#`(```$D6G]``)IZL`".,@K_C_
M`J>$`""Y!``YP.7___43N00`@NPH__(`?)4`(`"GA/_MP.7___5W["C_Z`!^
MN00`*,#E___QB;D$`++L)@`=`'Q!H/"XX["@```"IX0`%94`L`"GA`"7N00`
M*\#E___U6NPF`((`?J>K``CCL*````*G=/_OIP@``+D$`%:Y!``KISD``*=)
M``"R7@`RIQ3__K)>`$6G%/_^N0D`.[D)`$8:-*<Z!`2Y%`"CN00`*L#E___O
M^N-@\*``)+D$`(+`,```$A.Y!`!+P&```!(+P%```!&2P.7___%WN00`**<Y
M`<#`Y?__\E#L)@`+_W[`Y?__\;I8`"``[`8!91%^N00`*$$P\1C`Y?__\)X8
MLNPF``T`?EA@\3"GZ$``P&L``/``[&X`>(!VN00`6.-`T```!,2(``!"RL`P
M```1^>,@@```!,#E___P/Z>I``#5!_'8<"BG=`'DN00`*NMO\A``!`?^N00`
M*Z>K``C`Y?__\.NY!`"R["C_9P!\I_3_?*>Y``"G]/]X0:#PT.,@H````J>$
M`!6Y!``YP.7___1*["@`!P!\E0`@`*=T`!FGJP`(XR"@```"IW3_[Z<I``W`
M@```$8C`Y?__[VZG2`!3N00`LKD$`&*G]/[SP.7___"SN00`@NPH_^0`?+D$
M`!*G"```I^D``+)>`.&G%/_^N0D`XNLN``$`#:<K``&G]/[*6&#Q-,#E___O
M)NQB_X9@=E@0\3"G.`'`P!L```'_[!/_?&!VN00`*L#E___O-+D$`#FY!`"B
MP"```!&;P.7___/PN00`,NPH`-H`?.,@T```!,#E___W@;D$`&+L*`#/`'RG
M"```ITD``+D$`":R7@!"IQ3__KD)`$;L3``>`WZY%`!4P.```!%WXQ5O_/]Q
MLET`X:<4__ZG=``/[$@!%01^ITK_^[D4`#1!0V``E2]``*>$`0JY!``YP"``
M`!"TP.7___.N["@`GP!\XY`@``"4[)@`F0!^[)@`EC!^P#```!#:P"```!"?
MP.7___4!P.7__^Y@P````!&FN00`8KD$`$BY!``JXP#PH``DP%```!!IP#``
M`!%#P.7___!+I_0`*L#E___PEEA`(`"G3@`1IW0`*\#E___N/<!0```1@Z>Z
M``&Y%``;N00`8N-0\*@`)+D$`$BY!``JP%```!!"XQ#PH``DP#```!$@P.7_
M__`AN00`*J<Y`<#`Y?__\/KL*/_1_WZY!``HP.7___$RN00`.L`@```0&,#E
M___TJ+D$`"K`Y?___3^G]/[(N00`6+D4`&#C0-````3$*```07O`,```$(SC
M("````3`Y?__[O"G]/ZQP.7___TEU0?QV'`HIW0`DKD$`"OK;_(0``3`]/__
M[Y[C8-````2G]/\QN00`)J<Y``#`Y?__\&*Y!`#2["C_9`!^P.7___ODN00`
M8NPD_UP`?*=)``#C,&_V_W&Y!``MP.7__^YKN00`+4$P\:FG20`&P.7__^\"
M["8`7P9\P#```"_+U04P`/&IIW3_/>,P;\[_<:=)``"Y!``MP.7__^Y-06#Q
MK[D$`"VY!``VITD`*,#E___NXNPF`#\H?,#@```0U;D$`$BY!``JD@#QU^/@
M\*``),!0```/F,`P```0:L#E___O>J?T_V/CT-`(``*GA/[UIP@``*<I``"Y
M!`!=LEX`):<4__ZY"0`M["S^YP-]X^+?_/]QP!```!!"LET`'J<4__ZYXH!M
MI_3^V,#E___N$\`@```0-\#E___[*^MO\#``)./P_U#_<<"@``!`RK)/`+#C
M$*````3KNP`@``VR3P"QXY&P```$08#PI-('\*BP*-(`D+&0L+D$`#C`(```
M#U7`Y?__\EWL*``'`'R5,2``IX0`S<#E___W]^,@H```!..2L```!+D$`"FG
M60`#ITD``<`P```0$\#E___O&[D$`&+L*``?`'SC,"`0``3C<*````3C,#``
M``3`0```$`#C)[````3`Y?__[>3C0&`0``3C,$````210#`-IW0`NN-PH```
M!*=9``/C)[````2G20`!P#````_FP.7__^[JN00`DNPH`!P`?+D$`#C`(```
M#N#`Y?__\@.Y!`!"["@`?`!\XS"0$``$XR>P```$XS`P```$P.7__^VLXZ"@
M```$ITD``>-ZL```!,`P```/N[D$`"?`Y?__[ES`0```#[ZY!``RN00`)\#E
M___MDKD$`#C`(```#JCCBK````22`("QP.7___'+Q"L``$"$["@`*P!\ISD!
MP,#E___O:NP"``$`V.P,`!<!?^PH`!01?KD$`%+$N```0&K$2```0&OC,+``
M``3`(```#YS`Y?__[$#5!_"HL"BG=`!7ZV_PX``$!_[$*```0%+`Y?__^_O$
M*P``0%#L)O_/`'S`(```#W#`Y?__["65`"`!IX3_/*?T_S'`Y?__](:Y!`!B
M["@`(`!\XQ"0$``$N00`0N,P$```!.,GL```!,#E___M*;D$`";`Y?__[U2G
M]/]XXR>P```$P.7__^Q,I_3_0N-0D!``!,3H``!`$N,GL```!.,P4```!.-`
MX```!,#E___M"*?T_US`Y?__[-,'!P<'ZY_P2``DX_#_4/]QLD\`H+D$`++K
MJ@`@``U!,/"DLD\`H<`@```.-M('\*B@*,#E___Q+>PH`!,`?.,0(```E.P8
M``T`?NP8``HP?NRX``<`?)4`L`"G=``+U0?PJ*`HIW0`-.N?\/@`!`?^N00`
M*\#E___U_*<Y`"^Y!`"2P.7__^RO["@`!0!\09`@`;D$`"G`Y?__[86G20`$
MP#````Y.P.7__^T=[";_V0!^U0?PJ*`HIW0`"KD$`"OKG_#X``3`]/__\9O`
MY?__[&H'!^MO\#``)./P_-#_<;)/`+#KNP`@``VR3P"Q01#PJ-('\RBP**<)
M``1!4"`XXT!0```$XS!0"``$ZZ0`(``,XZ`0```DZV,`(``,XV`0$``DP$H`
M````XT`0"``DP#H`````XS`0&``D05!0$*<;`""G!__>XS#Q$``$XX#Q&``$
MXQ#Q(``$XY#PJ``$XP#PL``$04#PN*>I`$"Y!`!QX]!````$N00`[>/@0#``
M@KF"`..Y@@#I[!X@OR%5[!X@/@%6XQ!`<``DN00`.+D$`)"Y!`"'ITL`"*>G
M"MCCX"````3C8"`(``3C8/"@`"3C0"`0``3C`"`8``3LKB"_)56YYP"4[*X@
M.@56N8``EKF"`)#K5@`"``SC</"P``3L5@`A'E;">EJ">9GL-2"_`%6Y"`!P
MN><PU.,0\*@`!+F``-["&EJ">9FY@@#4XQ`@(``(N>APC;D(`!KKK@`"``RY
M"``9[*X`(1Y6[)$@OP!5N>>@9;F``&FY@@!C[-$[OR55XU#PP``$[-D`.@56
MPEI:@GF9N0@`V+D(`%/L?2"_`%7LC3N_)57K.0`"``SLAP`Z!5;L.0`A'E;C
M$/"X``3"&EJ">9FY"``4N0@`%NQJ(+\`5;F"`*.Y"``8N>1PBNR1(+\`5>S1
M.[\E5;D$`*WLJ0`Z!5:Y@@"&XQ#PR``$N0@`A<(:6H)YF;D(`(JYZ&!1ZZ<`
M`@`,[&,@OP!5[*<`(1Y6['@@OP!5[(@[OR55[(<`.@56N8(`.N/0\-``!+F`
M`#G"VEJ">9FY@@`VN0@`-;GH8%VY"``X[&H@OP!5ZXD``@`,[(D`(1Y6[),@
MOP!5N8(`J.PS.[\E5;GD<!KCT/#8``2Y@@`6PMI:@GF9N0@`%;D$`*.YZ&!=
M[*D`.@56[&@@OP!5N0@`&NLW``(`#.PW`"$>5KF"`(/L<2"_`%7LH3N_)56Y
MY)`8N00`BNR'`#H%5KF"`!;CT/#@``2Y"``5PMI:@GF9N0@`&+GH8%WLH3N_
M)57L8R"_`%7KB0`"``SLB0`A'E;LD2"_`%7LJ0`Z!5:Y@@`XXQ#PZ``$N8``
M-\(:6H)YF;F"`#:Y"``UN>A@4;D(`#KL:""_`%7KIP`"``SLIP`A'E:Y@@"*
M[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#P\``$N0@`-<(:6H)Y
MF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5;GD
M<#JY!`"M[*D`.@56N8(`-N,0\/@`!+D(`#7"&EJ">9FY"``ZN>A@4>NG``(`
M#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"
M`#;C$/$```2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y
M@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#Q"``$N0@`-<(:
M6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`5>S3.[\E
M5;GDD#BY!`"-[(<`.@56N8(`-N,0\1``!+D(`#7"&EJ">9FY"``XN>A@4>N)
M``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7LTSN_)56YY'`ZN00`K>RI`#H%
M5KF"`#;C$/$8``2Y"``UPAI:@GF9N0@`.KGH8%'KIP`"``SL:""_`%7LIP`A
M'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#Q(``$N0@`
M-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3
M.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\2@`!+D(`#7"&EJ">9FY"``ZN>A@
M4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'
M`#H%5KF"`#;C$/$P``2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7L
MB0`A'E:Y@@"H[),@OP!5[-,[OR55XQ#Q.``$N>1P.L(:6H)YF;F"`#:Y!`"M
MN0@`->RI`#H%5KGH8%&Y"``Z[&@@OP!5[-,[OR55ZZ<``@`,[-,@.@56[*<`
M(1Y6P#H`````N>>@>..`\4``!+F``'G"BEJ">9FY@@!VN>A@&+D(`'7K60`"
M``RY"`!][%D`(1Y6[)<[OR55[)<@.@56[&H@OP!5N>=0VNN#``(`#+F``-.Y
M@@#6N0@`T;D(`-FY!`"8[),`(1Y6[#T[OR55N>>0%>P](#H%5KF"`!?CH/%(
M``3C@/%0``3"JF[9ZZ'"BF[9ZZ&Y"`"FN1H`A;D:`*'L9R*_/E6Y"`"C[&<"
M(1Y6[#H[OR55N>=@&>PZ(#H%5KF"`!WL?2*_/E6Y&@"!['T"(1Y6N0@`@^,P
M\5@`!,(Z;MGKH;GG<%:Y&@`YN>>@E>P8.[\E5;D:`#GL&"`Z!5;CD/%@``2Y
M"``QPIINV>NA[-,[OR55N1H`ENS3(#H%5NQJ(K\^5>QJ`B$>5N.@\6@`!+GG
M8%?"JF[9ZZ&Y@@!8N1H`I[D:`)7L>"*_/E6Y"`"=['@"(1Y6[(D[OR55[(D@
M.@56N>=PUK/!`&CC@/%P``3"BF[9ZZ&Y&@"&L\T`9KF"`-.Y&@"MN0@`INQ:
M.[\E5>Q:(#H%5NQC(K\^5>,0\7@`!.QC`B$>5L(:;MGKH;GG8#>Y&@`7N8(`
M.>QY(K\^5;D:`(/L>0(A'E:Y"`"%N>=P5NR8.[\E5;F"`%KLF"`Z!5:Y&@`5
MXS#Q@``$N0@`&<(Z;MGKH>R:(K\^5;D:`#;LF@(A'E;LT3N_)56YYY!7[-$@
M.@56N8(`6..@\8@`!+D:`#7"JF[9ZZ&Y"``]N1H`I^QX(K\^5>QX`B$>5NR#
M.[\E5>R#(#H%5KGG<-FSP0!XXX#QD``$PHINV>NAN1H`B;/-`)>Y@@#1N1H`
MK;D(`*GL6CN_)57L6B`Z!5;L82*_/E7L80(A'E;C$/&8``2YYV#7PAINV>NA
MN8(`T[D:`!>Y&@"-[',BOSY5N0@`A>QS`B$>5NPX.[\E5;GG<%;L."`Z!5:Y
M@@!:XY#QH``$N1H`%<*:;MGKH;D(`!.Y&@"6[#HBOSY5[-$[OR55[#H"(1Y6
M[-$@.@56N><P5^.@\:@`!+F"`%C"JF[9ZZ&Y&@"5N1H`I[D(`)WL>"*_/E7L
M>`(A'E;LB3N_)57LB2`Z!5:YYW#3L\$`:..`\;``!,**;MGKH;D:`(.SS0`V
MN8(`T;D:`*VY"`"C[%H[OR55[%H@.@56[&$BOSY5[&$"(1Y6XQ#QN``$N>=@
MU\(:;MGKH;F"`-FY&@`7N1H`C>QY(K\^5;D(`(7L>0(A'E;LF#N_)56YYW!6
M[)@@.@56N8(`6N,P\<``!+D:`!7".F[9ZZ&Y"``9N1H`-NR:(K\^5>S1.[\E
M5>R:`B$>5NS1(#H%5KGGD%?CH/'(``2Y@@!8PJINV>NAN1H`-;D:`*>Y"``]
M['@BOSY5['@"(1Y6[(,[OR55[(,@.@56N>=PV;/!`'CC@/'0``3"BF[9ZZ&Y
M&@")L\T`E[F"`-'L82*_/E6Y&@"M[&$"(1Y6N>=@U[F"`-.Y"`"IN1H`C>Q:
M.[\E5>S3(K\^5>Q:(#H%5NS3`B$>5KGGT):Y@@":N0@`A>,0\=@`!.PX(+\`
M5>Q8.[\E5<(:;MGKH>Q3`#H%5KD:`!>Y&@`9[)HBOSY5N0@`%>R:`B$>5N.@
M\>``!+GGD'W"JF[9ZZ&Y@@"'N1H`INQA(+\`5>P1.[\E5>P6`#H%5KD:`*CC
M@/'H``2Y"`"APHJ/&[S<ZQ,``@`,N1H`C>P3`"$>5NS1(+\`5;GDT%FSP0`H
M[#H[OR55[(H@OP!5N>80J;F``*:Y@0"EL\T`4N-P\?``!,)ZCQN\W.PX`#H%
M5KD(`*6Y!`!7XW#Q^``$N1H`6<)ZCQN\W.N6``(`#.R6`"$>5KGDT&FY@0`9
MN>C0U[F``!BY@0`6N0@`%;D(`*.SP0!M[#H@OP!5[*H[OR55[*,`.@56N0@`
MH>L8``(`#.P8`"$>5NS1(+\`5;GDT%GL:B"_`%7LBCN_)56YYA"IN8``H[F!
M`*6SS0!6[(8`.@56XW#R```$N0@`I;D(`*C">H\;O-SK@P`"``RY!`!7[(,`
M(1Y6N1H`6>PZ.[\E5>R:(+\`5;F!`!BYY-"HN8``%KF!`!JY"``5[#D`.@56
MXW#R"``$N0@`,<)ZCQN\W.L6``(`#+GHT-?L%@`A'E;L82"_`%6YY&!8L\$`
M/;GF$-BY@`#9N8$`U;/-`%/L<R"_`%7L,SN_)57L-P`Z!5:Y"`#5N0@`T^LY
M``(`#.PY`"$>5KGD8).Y@0`3XZ#R$``$N8``%\*JCQN\W+F!`!FY!`!:N1H`
M6.R-(+\`5;D(`!7LW3N_)57LV``Z!5:Y"`#1[)T@OP!5ZQ<``@`,[!<`(1Y6
MXW#R&``$PGJ/&[S<N>A@9^QQ(+\`5;GD<%.YYA"CL\$`=KF``*BY@0"EL\T`
M5^S=.[\E5>-@\B``!+D(`*7LV0`Z!5;":H\;O-RY"`#:N00`5NRM(+\`5;D:
M`%/LW3N_)57K.``"``SLV@`Z!5;L.``A'E:YYC"!N>1P$[F``(FY@0"!ZQD`
M`@`,N0@`A>P9`"$>5KD(`(WLT2"_`%6YY-!3N>80D^-@\B@`!+F``)K":H\;
MO-RY@0"5N0@`9[/!`":SS0!2['@@OP!5XV#R,``$N0@`E<)JCQN\W.R(.[\E
M5;D$`%;LAP`Z!5:Y&@!3N>B`.>N:``(`#.R:`"$>5KGDT*FY@0`9N8``%[F!
M`!JY"``5[(,@OP!5[&,[OR55XS#R.``$[&@`.@56PCJ/&[S<N0@`8>L7``(`
M#.P7`"$>5NQQ(+\`5;GD<%FYZ-#3N>80.;/!`&VY@``XN8$`-;/-`%;CT/)`
M``3"VH\;O-SLIB"_`%6Y"``U[&8[OR55N00`7>QJ`#H%5KD:`%GCT/)(``3K
MF``"``S"VH\;O-SLF``A'E:YY'")N8$`&;GH<'VY@``:N8$`&+D(`!6Y"``V
ML\$`-^QC(+\`5>PS.[\E5>PV`#H%5KGH,%'K&@`"``SL&@`A'E;LT2"_`%6Y
MY-!YN>80J;F``*:Y@0"GL\T`<^PU(+\`5>R%.[\E5;D(`*?L@P`Z!5:Y"`"H
MXU#R4``$['H@OP!5[(H[OR55PEJ/&[S<XZ#R6``$N1H`6<*JCQN\W.N6``(`
M#.R6`"$>5KGDT&FY@0`9N>C0VKF``!.Y@0`6N0@`%>R'`#H%5K/!`'VY"`"!
MZQ,``@`,[!,`(1Y6[-$@OP!5N>306;GF$*FY@`"GN8$`I;/-`%?L:""_`%7L
M.#N_)56Y"`"E[#8`.@56XX#R8``$PHJ/&[S<N00`6+D:`%GKEP`"``SLEP`A
M'E:YY-!YN8$`&;F``!:Y@0`7N0@`%;D(`*/C@/)H``3L.B"_`%7"BH\;O-SL
MJCN_)57LHP`Z!5:Y"`"AZQ8``@`,[!8`(1Y6[&$@OP!5N>1@6>QZ(+\`5;GH
MT-CLBCN_)56SP0`MN>80J;F``*.Y@0"EL\T`4NR'`#H%5N/0\G``!+D(`*7"
MVH\;O-RY"`"HN00`7;D:`%GLVB"_`%7KDP`"``SLDP`A'E;L.CN_)56YY&")
MN8$`&>P]`#H%5KF``!?CH/)X``2Y@0`8PJJ/&[S<N0@`%;GH8%JY"``Q[&,[
MOR55[&,@.@56ZQ<``@`,L\$`9NP7`"$>5N-@\H``!.R!(+\`5;GF$'FYY("I
MPFJ/&[S<N1H`:;/-`):Y@`!]N8$`>KD(`'6YZ)"7[%D[OR55[%D@.@56L\$`
M%NM]``(`#.Q]`"$>5KD$`-6SS0!1N>2`I^-@\H@`!,)JRF+!UKGH@(;`.@``
M``"Y@0`7L\$`.+F``!/K@P`"``RY@0`:[(,`(1Y6N0@`%;/-`&.Y"``=XZ#R
MD``$N>>`U\*JRF+!UKF"`-FY&@"G['DBOSY5['D"(1Y6XY#RF``$PIK*8L'6
MN1H`F+/!`%JSP0`)L\T`E;D:`&WL,3N_)57L,2`Z!5:Y"``V[%,[OR55[%,@
M.@56N>=PJ+F"`*&Y&@":N0@`E;/-`%#L82*_/E7L80(A'E:YYV#7N8(`T^P9
M.[\E5;D:`%WL&2`Z!5:Y"``5[*$[OR55[*$@.@56L\$`*K/-`-+C@/*@``3C
MH/*H``3"BLIBP=;"JLIBP=:Y&@"'N1H`INQS(K\^5>QS`B$>5KGG<#;L:2*_
M/E6Y@@`Y[&D"(1Y6N1H`@[GG8%>Y"`"-N8(`4>R8.[\E5;D:`*7LF"`Z!5:Y
M"`"I[-H[OR55[-H@.@56[)$BOSY5XS#RL``$[)$"(1Y6PCK*8L'6N>>05KD:
M`#>Y@@!8N1H`-;D(`#WLTSN_)57LTR`Z!5;C$/*X``2SP0`=PAK*8L'6X]#R
MP``$N1H`%L+:RF+!UNQH(K\^5;D:`-GL:`(A'E:YYV")L\T`D;F"`(KL>B*_
M/E6Y&@`8['H"(1Y6N0@`&;GG<(;L43N_)56Y@@"#[%$@.@56XZ#RR``$PJK*
M8L'6N1H`IKD$`&WLTR*_/E6Y&@!HN0@`9>S3`B$>5KGGT#>Y@@`Q[%8[OR55
MN1H`H^Q6(#H%5KD(`*7L.CN_)57L.B`Z!5;C@/+0``3"BLIBP=:Y&@"'['$B
MOSY5['$"(1Y6XQ#RV``$N>=P7<(:RF+!UKF"`%:Y&@`=N1H`A>S6(K\^5;D(
M`(/LU@(A'E;L.#N_)56YY]!G[#@@.@56N8(`:KD:`!:Y"``3[#HBOSY5[#H"
M(1Y6N><P;;F"`&CL43N_)57CD/+@``3L42`Z!5;"FLIBP=:Y&@"7N1H`ENQH
M(K\^5;D(`)7L:`(A'E;LB3N_)57LB2`Z!5:YYV!SL\$`2..`\O``!,**RF+!
MUKD:`(.SS0`TN8(`<>.@\N@`!,*JRF+!UKD:`*VY&@"G['$BOSY5N0@`H^QQ
M`B$>5NQ:.[\E5;GG<-;L6B`Z!5:Y@@#9XQ#R^``$N1H`C<(:RF+!UKD(`(6Y
M&@`6[&DBOSY5[&D"(1Y6[)@[OR55N>=@5^R8(#H%5KF"`%JY&@`5N0@`&>S1
M.[\E5>S1(#H%5NR:(K\^5>,P\P``!.R:`B$>5L(ZRF+!UKGGD%:Y&@`WN8(`
M6+D:`#6Y"``][-,[OR55[-,@.@56XZ#S"``$L\$`7<*JRF+!UN/0\Q``!+D:
M`*;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6N>=@B;/-`)6Y@@"!N1H`J.R!(K\^
M5>R!`B$>5KGG@':Y@@!SN0@`J;D:`-?L6CN_)57L<R*_/E7L6B`Z!5;L<P(A
M'E:Y!``WXS`@(``(P#H`````XS`@(``DXQ#S&``$PAK*8L'6N1H`%KGH4&VY
MYW#8[)8@OP!5N>>@/>Q6.[\E5;D:`!/L60`Z!5:Y"``5[-HBOSY5ZUD``@`,
M[-H"(1Y6[%D`(1Y6N>?0-[D(`%2YZ`!]P%H`````XU`@$``DN>=@`\!Z````
M`.-P(!@`).QA(+\`5>.@\R``!,*JRF+!UKD(`.JY&@#H[($[OR55N1H`X.R&
M`#H%5N,0\*``!+D(`.BY"``6P.H`````X^`@```DP!H`````XQ`@"``DU0?S
M*+`HIW0`"NMO\V``!`?^N00`#:?T]0?`Y?__X1X'!^OO\'``)*<I`(#C\/]@
M_W'`Y?__X,+`,6=%(P'`#^_-JXGC,"```"3C`"`(`"3`3YBZW/[`41`R5';C
M0"`0`"3C4"`8`"3`/\/2X?#E2"`H``#C,"`@`"3E2"`P``#E3"!X``#K[_$0
M``0'_@<'!P?K;_`P`"3K%``#``VY!`!RXR`@*``$N0@`$NQ1(+\`5;D$`+3C
M\/]8_W'C0'`P``2Y!`#3N3$`(:?$``2G2P`!XU!P*``DZPL`'0`,N0@`!.,`
M<#``).,P<'@`$J=T`&1!8'`X[+P`.#]^[.O_P`#8[)T`0`#9ZXX`!@#>IXH`
M`1+NIQ@``;GR4(%!('!XN00`K>,@\*``)+DA`&JGI``UXU#PH``$[%H`-R!E
MN00`V=(_8`"@`+D$`">GNO_`IZL`0,#E___T&[D4`+NGFP!`IX;_Y+DA`&VG
M1``@I\0`!KGHL$VY84!DN00`/;D$`":Y!`!+P.7__]^X4+!P>.MO\-@`!`?^
MN00`V:?$_]/L:?_1H&6G]``!N>BP!KEA0-"G]/_DIZ@`0!NC&:M!8'`XN?(P
MJ[D$`":Y&``CN10`2NPM`"*@9;GH0(*YZ$"=N6%`V+D$`#T8VL#E___?AEK0
M<'A0T'!X[-;_S$!^N00`)QNZN00`V<#E___SP;D4`+NG]/]RN>A`G>PM_^7`
M9;EA0"FG]/_@!P?K?_`X`"2Y!`"SXX`P*``$XY`P,``$[!@ZOSU5N10`,4%#
ML#B2@$``IQH``;D$`**Y%``!02"P../P_V#_<;D(`"#L'`">.'ZGZ`!`N?D0
M/NSA`%^`=NP3__\`V+D$`#+K00`(`-[L2`!/`'[L=/__`-@85.P$/K\`5:>$
M`";L"``9`7[L"``,`G[C("0``#881T$P(0#7_R``(`#C(#0``#:G2O__U_\P
M`#``03`Q`.,@-```-M?_,``P`$$P,0#L2``B`7[K)0`"`-[C(#0``#;7_S``
M,`#C(#4``#;7_S$`,0#C(#8``#;7_S(`,@#C(#<``#;7_S,`,P!!,#0`IR;_
MYKD6`.'&X````*"Y!``KP.7___,GUS>P.+`XISD``.PY``=@5>PY"`]@5>PY
M$!=@5>PY&!\@5;D$`"OL@P`?`%7C@+!P`"3`Y?__\PO2`Z``L`2Y!``KT@.@
M!+`,T@.@"+`4T@.@#+`<T@.@$+`DZW_PV``$P/3__^&ZIU@`.+GY$'7L4?_,
M@';L%___`-BY!``RZW$`"`#>['@`3P!^[.?__P#8&%?L!SZ_`%6GA``F[`@`
M&0%^[`@`#`)^XR`D```V&'Y!,"$`U_\@`"``XR`T```VIWK__]?_,``P`$$P
M,0#C(#0``#;7_S``,`!!,#$`['@`(@%^ZT4``@#>XR`T```VU_\P`#``XR`U
M```VU_\Q`#$`XR`V```VU_\R`#(`XR`W```VU_\S`#,`03`T`*=&_^:Y%@`A
MQB`````(I_3_;=<`,``P`-<`,``P``<'!P?K[_!P`"2Y!``/I_O_8.,`\```
M).OO\1``!`?^`````"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I+R5S`"X`4$%2
M7U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%
M4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!0
M05)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'
M``!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@``,0!L<V5E:R!F86EL960``')E860@9F%I
M;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@``'!A<BT``"5S)7,E
M<R5S```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*``!0051(``!P87)L```N<&%R``!S:&]R="!R96%D```E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#8S`%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```M90``+2T``%5315(``%5315).04U%``!414U01$E2`%1-4``O=&UP
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````````'!E<FQX<VDN8P``0T%#
M2$4```````````$;`SL```#4````&?__@A@```54__^&(````/#__X<````!
M4/__AY````&`__^(\````;C__XMX```!^/__B_````(T__^,*````DC__XU0
M```"C/__C5@```*@__^/R````N#__Y`````##/__D6@```-0__^6^````X3_
M_Y=P```#M/__E^@```/@__^9^```!"3__YHH```$1/__FN@```2`__^A(```
M!-#__Z.8```%$/__I&@```68__^[````!=C__[MP```%_/__O0@```8X````
M`````!0``````7I2``%X#@$;#`^@`0```````%P````<__^%*````-P`1H8.
MAPV(#(D+B@J+"8P(C0>.!H\%1@[``@*8"L_.S<S+RLG(Q\8.H`%""UP*S\[-
MS,O*R<C'Q@Z@`4(+3@K/SLW,R\K)R,?&#J`!0@L``````"P```!\__^%J```
M`)``1HH*BPF,"(T'C@:/!48.V`,"?`K/SLW,R\H.H`%""P```#0```"L__^&
M"````6``1H@,B0N*"HL)C`B-!XX&CP5&#M@#=@K/SLW,R\K)R`Z@`4(+````
M````/````.3__X<P```"B`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M@"`P%6
M"L_.S<S+RLG(Q\8.H`%""P```````#@```$D__^)>````'0`3(8.APV(#(D+
MB@J+"8P(C0>.!H\%1@[(`@)@S\[-S,O*R<C'Q@Z@`0```````!````%@__^)
MM````#@`````````0````73__XG8```!)`!&A@Z'#8@,B0N*"HL)C`B-!XX&
MCP5&#J`A3`Z@04P.T$("Y`K/SLW,R\K)R,?&#J`!0@L````0```!N/__BKP`
M```&`````````#P```',__^*L````FP`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M1@Z@(4P.Z",">@K/SLW,R\K)R,?&#J`!0@L````H```"#/__C.`````T`$J+
M"8P(C0>.!H\%1@[``E[/SLW,RPZ@`0```````$````(X__^,[````6(`1HH*
MBPF,"(T'C@:/!48.H"%,#L@B`O0*S\[-S,O*#J`!0@M<"L_.S<S+R@Z@`48+
M````````,````GS__XX0```%C`!&B@J+"8P(C0>.!H\%1@[0`@,%2@K/SLW,
MR\H.H`%&"P```````"P```*P__^3;````'8`3(L)C`B-!XX&CP5&#M`"`E0*
MS\[-S,L.H`%""P```````"@```+@__^3M````'0`7(8.APV(#(D+B@J+"8P(
MC0>.!H\%1@[H`@``````0````PS__Y0````"$`!&B`R)"XH*BPF,"(T'C@:/
M!48,#J"!!%@-#T8.T(($`P&D"L_.S<S+RLG(#J`!0@L````````<```#4/__
ME<P````L`$:.!H\%1@[``E[/S@Z@`0```#@```-P__^5W````,``1H8.APV(
M#(D+B@J+"8P(C0>.!H\%1@[0`@)4"L_.S<S+RLG(Q\8.H`%&"P```$P```.L
M__^68```!C@`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@Z`!0,"8`K/SLW,R\K)
MR,?&#J`!0@L#`J(*S\[-S,O*R<C'Q@Z@`48+````/````_S__YQ(```"=`!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P&^"L_.S<S+RLG(Q\8.H`%""P``
M`````$````0\__^>@````,X`1HD+B@J+"8P(C0>.!H\%1@[0`@)>"L_.S<S+
MRLD.H`%""P)6"L_.S<S+RLD.H`%&"P``````0```!(#__WR\```"@`!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5&#N@"`P'`"L_.S<S+RLG(Q\8.H`%""P``````
M```````\```$Q/__GL@``!:6`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`<#
M%GH*S\[-S,O*R<C'Q@Z@`4(+````````(```!03__[4@````;`!*C@:/!48.
MP`("6L_.#J`!````````.```!2C__[5L```!E@!,A@Z'#8@,B0N*"HL)C`B-
M!XX&CP5>#L@"`MH*S\[-S,O*R<C'Q@Z@`4(+````.```!63__[;(```"5`!&
MAPV(#(D+B@J+"8P(C0>.!H\%>`[``@,!.@K/SLW,R\K)R,<.H`%&"P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````C$````````"*H``````````$````````"P@``
M```````!`````````LT`````````'0````````/_``````````P````````8
M*``````````-````````7)``````````&0```````+O(`````````!L`````
M````"``````````:````````N]``````````'``````````(`````&___O4`
M```````">``````````%````````#$``````````!@````````-8````````
M``H````````$'0`````````+`````````!@`````````%0``````````````
M``````,```````"]N``````````"````````!2@`````````%``````````'
M`````````!<````````3```````````'````````$&``````````"```````
M``*@``````````D`````````&``````````>``````````@`````;___^P``
M```(```!`````&____D`````````$```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````N]@`````````````````````````````&'(`
M```````8D@```````!BR````````&-(````````8\@```````!D2````````
M&3(````````94@```````!ER````````&9(````````9L@```````!G2````
M````&?(````````:$@```````!HR````````&E(````````:<@```````!J2
M````````&K(````````:T@```````!KR````````&Q(````````;,@``````
M`!M2````````&W(````````;D@```````!NR````````&](````````;\@``
M`````!P2````````'#(````````<4@```````!QR````````')(````````<
ML@```````!S2````````'/(````````=$@```````!TR````````'5(`````
M```=<@```````!V2````````';(````````=T@```````!WR````````'A(`
M```````>,@```````!Y2````````'G(````````>D@```````!ZR````````
M'M(````````>\@```````!\2````````'S(`````````````````````````
M```````````````8*```````````````````````````````````````````
M```````````````````?2```````````````````7)``````````````````
M``````````````````````#```I005(N<&T*``````````````````!?G```
M`````%SX``````````````````!=F````````%V<````````7Y````````!<
M_@```````%^8``````````````````!?@````````%^&````````````````
M``!?HD=#0SH@*$%L<&EN92`Q,RXR+C%?9VET,C`R-#`S,#DI(#$S+C(N,2`R
M,#(T,#,P.0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`
M+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````L````!``````````(````````".`````````(X`````````!@`````
M```````````````!```````````````3````!P`````````"`````````E``
M```````"4``````````D````````````````````!```````````````)F__
M__8``````````@````````)X`````````G@`````````W`````0`````````
M``````@``````````````#`````+``````````(````````#6`````````-8
M````````".@````%`````@`````````(`````````!@````X`````P``````
M```"````````#$`````````,0`````````0=`````````````````````0``
M````````````0`````0``````````@```````!!@````````$&`````````"
MH`````0```````````````@`````````&````$H````$`````````$(`````
M```3`````````!,`````````!2@````$````$@`````````(`````````!@`
M``!4`````0`````````&````````&"@````````8*``````````<````````
M`````````````@``````````````3P````$`````````!@```````!A$````
M````&$0````````'``````````````````````0`````````(````%H````!
M``````````8````````?2````````!](````````/4@`````````````````
M```(``````````````!@`````0`````````&````````7)````````!<D```
M```````<`````````````````````@``````````````9@````$`````````
M`@```````%RP````````7+````````!`@`````````````````````@`````
M`````````&X````!``````````(```````"=,````````)TP`````````-0`
M```````````````````$``````````````!\`````0`````````"````````
MG@@```````">"`````````6@````````````````````"```````````````
MA@````X``````````P```````+O(````````J\@`````````"```````````
M``````````@`````````"````)(````/``````````,```````"[T```````
M`*O0``````````@````````````````````(``````````@```">````!@``
M```````#````````N]@```````"KV`````````'@````!0``````````````
M"``````````0````IP````$``````````P```````+VX````````K;@`````
M```"2`````````````````````@`````````"````*P````!``````````,`
M``````#``````````+```````````(`````````````````````(````````
M``````"R````"``````````#````````P(````````"P@`````````!8````
M````````````````"```````````````MP````$`````````,```````````
M````````L(``````````,0````````````````````$``````````0````$`
M```#`````````````````````````````+"Q`````````,``````````````
.```````!````````````
